@@ -18,9 +18,9 @@
 (require 'asdf)
 (require 'sb-posix)
 
-(asdf:oos 'asdf:load-op 'restorecluster)
+(asdf:oos 'asdf:load-op 'deletecluster)
 
-(sb-ext:save-lisp-and-die "restorecluster"
+(sb-ext:save-lisp-and-die "deletecluster"
  :executable t
- :toplevel #'Scat.showcluster::toplevel
+ :toplevel #'Scat.deletecluster::toplevel
  :purify NIL)
