@@ -15,8 +15,8 @@
 ;;;; along with this program; if not, write to the Free Software
 ;;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-(defpackage :edu.unm.hpc.Scat.showcluster
-  (:nicknames :Scat.showcluster)
+(defpackage :edu.unm.hpc.Scat.deletecluster
+  (:nicknames :Scat.deletecluster)
   (:use :cl
         #+allegro :clos
         #+cmu :pcl
@@ -27,7 +27,7 @@
         :Scat.Lib
         ))
 
-(in-package :edu.unm.hpc.Scat.showcluster)
+(in-package :edu.unm.hpc.Scat.deletecluster)
 
 (defvar *nodes* ())
 
@@ -43,14 +43,11 @@
                   :description "display this help text")
    (make-instance 'cli-opt
                   :name :default
-                  :arguments '(&optional noderange)
+                  :arguments '()
                   :action
-                  #'(lambda (&optional (noderange "all"))
-                      (setf *nodes* 
-                            (Scat.Lib::expand-nodelist noderange))))))
+                  #'(lambda () NIL))))
 
 (defun toplevel () 
-  (error "FIXME")
   (sb-sys:enable-interrupt sb-unix:SIGINT #'handle-ctrl-c)
   (read-scat-config)
   (handler-case
@@ -60,8 +57,10 @@
       (help *opts*)
       (cl-user::quit :unix-status 1)))
   (cl-cli::process-options *opts* (rest sb-ext:*posix-argv*))
-  (mapcar
-   (lambda (node)
-     (format t "~A ~A ~A ~A~%" node (scat.lib::list-mac node) (scat.lib::node->type node) (scat.lib::node-state node)))
-   *nodes*)
+  (let ((nodes (list-node-files)))
+    (mapcar
+     (lambda (node)
+       (format t "deleting node: ~A~%" node)
+       (delete-node node))
+     nodes))
   (cl-user::quit))
