@@ -25,9 +25,11 @@
         #+sbcl :sb-mop
         #+lispworks :hcl
         :cl-user
-        ;; :com.gigamonkeys.pathnames
+        :com.gigamonkeys.pathnames
         :osicat)
   (:export 
+   list-images
+   list-node-files
    node->type
    delete-node
    define-node
@@ -108,6 +110,20 @@
                 (format t "~%")
                 root))))))))
 
+(defun list-images ()
+  "list the node images"
+  (let* ((directory Scat.Cfg::*node-image-dir*)
+         (files (list-files-in-dir directory)))
+    (loop as file in files
+       for name =  (aif (directory-p
+                         (pathname-as-directory
+                          (merge-pathnames file directory)))
+                        it
+                        (merge-pathnames file directory))
+       for true = (truename (merge-pathnames file directory))
+       when (equal name true)
+       collect file)))
+
 
 ;;; node state query/manipulation functions
 
